"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLogoutHookData = void 0;
const yup_1 = require("yup");
const decodeAndSanitizeUrl_1 = require("../../helpers/navigation/decodeAndSanitizeUrl");
const parseQueryParams_1 = require("../../helpers/navigation/parseQueryParams");
const validUrlSchema_1 = require("../../hooks/helpers/validUrlSchema/validUrlSchema");
const sdkDappCore_1 = require("../../lib/sdkDappCore");
const schema = (0, yup_1.object)({
    callbackUrl: validUrlSchema_1.validUrlSchema.required()
}).required();
const getLogoutHookData = (search = window.location.search) => {
    if (!search) {
        return null;
    }
    const hook = (0, parseQueryParams_1.parseQueryParams)(search);
    try {
        schema.validateSync(hook, { strict: true });
        let callbackUrl = (0, decodeAndSanitizeUrl_1.decodeAndSanitizeUrl)(hook.callbackUrl);
        callbackUrl = (0, sdkDappCore_1.sanitizeCallbackUrl)(callbackUrl);
        return {
            hookUrl: search,
            callbackUrl
        };
    }
    catch ({ errors }) {
        console.error('logout hook format errors: ', errors);
    }
    return null;
};
exports.getLogoutHookData = getLogoutHookData;
//# sourceMappingURL=getLogoutHookData.js.map