"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.replyWithPostMessage = void 0;
const processBase64Fields_1 = require("../helpers/operations/processBase64Fields");
const sdkDappUtils_1 = require("../lib/sdkDappUtils");
const isUndefined_1 = __importDefault(require("lodash/isUndefined"));
const replyWithPostMessage = ({ postMessageData: props, callbackUrl, target }) => {
    if ((0, isUndefined_1.default)(props.payload.data)) {
        console.error('Unable to sign transaction', props.payload.error);
        return;
    }
    const data = props.type === sdkDappUtils_1.CrossWindowProviderResponseEnums.signTransactionsResponse
        ? props.payload.data.map((tx) => (0, processBase64Fields_1.processBase64Fields)(tx).encode())
        : props.payload.data;
    const isIframe = target instanceof HTMLIFrameElement;
    if (isIframe) {
        const { contentWindow } = target;
        if (contentWindow) {
            const currentIframeHref = new URL(target.src);
            const iframeOrigin = currentIframeHref.origin;
            contentWindow.postMessage({
                type: props.type,
                payload: {
                    data
                }
            }, iframeOrigin);
        }
        return;
    }
    const allowedResponses = [
        sdkDappUtils_1.CrossWindowProviderResponseEnums.handshakeResponse,
        sdkDappUtils_1.CrossWindowProviderResponseEnums.cancelResponse,
        sdkDappUtils_1.CrossWindowProviderResponseEnums.disconnectResponse
    ];
    const origin = allowedResponses.includes(props.type)
        ? '*'
        : String(callbackUrl);
    target.postMessage({
        type: props.type,
        payload: {
            data
        }
    }, origin);
};
exports.replyWithPostMessage = replyWithPostMessage;
//# sourceMappingURL=replyWithPostMessage.js.map