"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.replyWithRedirect = void 0;
const qs_1 = __importDefault(require("qs"));
const assignWindowLocation_1 = require("./assignWindowLocation");
const replyQsUrl_1 = require("./replyQsUrl");
const replyUrl_1 = require("./replyUrl");
const sdkDappUtils_1 = require("../../lib/sdkDappUtils");
const hooks_enum_1 = require("../../types/hooks.enum");
const sanitizeCallbackUrlSearchParams_1 = require("../../hooks/helpers/sanitizeSignHookCallbackUrl/sanitizeCallbackUrlSearchParams");
const sdkWebWalletProvider_1 = require("../../lib/sdkWebWalletProvider");
const objectValuesToString_1 = require("../../helpers/operations/objectValuesToString");
const buildSearchString_1 = require("../../helpers/navigation/buildSearchString");
const replyWithRedirect = ({ data, callbackUrl, transactionData }) => {
    let url = '';
    const { type, payload } = data || {};
    // URL reply
    switch (type) {
        case sdkDappUtils_1.CrossWindowProviderResponseEnums.loginResponse: {
            if (payload?.error || !payload?.data) {
                return;
            }
            const { address, signature } = payload.data;
            const urlParams = {
                address
            };
            if (signature) {
                urlParams.signature = signature;
            }
            url = (0, replyUrl_1.replyUrl)({ callbackUrl, urlParams });
            break;
        }
        case sdkDappUtils_1.CrossWindowProviderResponseEnums.disconnectResponse: {
            url = callbackUrl;
            break;
        }
        case sdkDappUtils_1.CrossWindowProviderResponseEnums.cancelResponse: {
            const urlParams = {
                address: payload?.data?.address ?? '',
                status: hooks_enum_1.HookResponseStatusEnum.cancelled
            };
            url = (0, replyUrl_1.replyUrl)({ callbackUrl, urlParams });
            break;
        }
        case sdkDappUtils_1.CrossWindowProviderResponseEnums.signTransactionsResponse: {
            if (!payload?.data) {
                console.error('Unable to sign transactions: ', payload?.error);
                break;
            }
            const plainTransactionsToObject = payload?.data.map((plainTransactions) => (0, objectValuesToString_1.objectValuesToString)(plainTransactions));
            const qsStr = qs_1.default.stringify({
                ...(0, buildSearchString_1.buildSearchString)(plainTransactionsToObject),
                [sdkWebWalletProvider_1.WALLET_PROVIDER_CALLBACK_PARAM]: sdkWebWalletProvider_1.WALLET_PROVIDER_CALLBACK_PARAM_TX_SIGNED
            }, { encode: false });
            const qsUrl = (0, replyQsUrl_1.replyQsUrl)({ callbackUrl, qsStr });
            url = (0, sanitizeCallbackUrlSearchParams_1.sanitizeCallbackUrlSearchParams)(qsUrl);
            break;
        }
        case sdkDappUtils_1.CrossWindowProviderResponseEnums.signMessageResponse: {
            if (!payload?.data) {
                console.error('Unable to sign message: ', payload?.error);
                break;
            }
            const urlParams = {
                status: payload?.data.status
            };
            if (payload?.data.signature) {
                urlParams.signature = payload?.data.signature;
            }
            url = (0, replyUrl_1.replyUrl)({ callbackUrl, urlParams });
            break;
        }
        default: {
            break;
        }
    }
    if (transactionData) {
        const urlParams = {
            address: transactionData.address,
            txHash: transactionData.txHash,
            status: transactionData.status
        };
        url = (0, replyUrl_1.replyUrl)({ callbackUrl, urlParams });
    }
    (0, assignWindowLocation_1.assignWindowLocation)(url);
};
exports.replyWithRedirect = replyWithRedirect;
//# sourceMappingURL=replyWithRedirect.js.map